from zafiaonline.transport.websocket_module import Websocket, Config
from zafiaonline.transport.http_module import Http, HttpWrapper

__all__: tuple[str, ...] = (
    "Websocket",
    "Http",
    "HttpWrapper",
    "Config",
    )



from zafiaonline.api_client.api_decorators import ApiDecorators
from zafiaonline.api_client.global_chat_methods import GlobalChat
from zafiaonline.api_client.player_methods import Players
from zafiaonline.api_client.room_methods import Room, MatchMaking
from zafiaonline.api_client.user_methods import Auth, User
from zafiaonline.api_client.https_api import HttpsApi
from zafiaonline.api_client.zafia_api import ZafiaApi

__all__: tuple[str, ...] = (
    #Decorators
    "ApiDecorators",

    #Chat
    "GlobalChat",

    #Players
    "Players",
    "Auth",
    "User",

    #Room
    "Room",
    "MatchMaking",

    #Other
    "HttpsApi",
    "ZafiaApi",
)



from zafiaonline.utils.exceptions import (
    ListenDataException,
    ListenExampleErrorException, BanError, LoginError
)
from zafiaonline.utils.md5hash import Md5
from zafiaonline.utils.utils_for_send_messages import Utils


__all__: tuple[str, ...] = (
    # Hash's
    "Md5",

    # Exceptions
    "ListenDataException",
    "ListenExampleErrorException",
    "BanError",
    "LoginError",

    # Utils
    "Utils",
)



"""
Copies non-callable attributes of a client object onto itself.

This module provides a utility function for copying all non-callable
attributes from a client's `__dict__` back to the client instance.

Intended for use in dynamic or reflective systems where attribute resetting
or propagation is necessary.
"""
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from zafiaonline.api_client.user_methods import Auth


def get_user_attributes(auth: "Auth") -> None:
    """
    Reassigns all non-callable attributes from a client's __dict__ to itself.

    Args:
        auth: The client object whose attributes will be reassigned.

    Returns:
        None
    """
    for key, value in auth.__dict__.items():
        if not callable(value):
            setattr(auth, key, value)
